@@ -1,10 +1,8 @@
 """Implement the ES-MDA algorithms."""
 __author__ = """Antoine Collet"""
 __email__ = "antoine.collet5@gmail.com"
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
-from .esmda import ESMDA
+from .esmda import ESMDA, ESMDA_RS
 
-__all__ = [
-    "ESMDA",
-]
+__all__ = ["ESMDA", "ESMDA_RS"]
